#!/bin/sh
#
# Run this after 'install' completes to edit the bes.conf scrip so that it
# will be correctly configured for the handler and the sample data.
#
# Usage: bes-fonc-data.sh [<bes.conf file to modify> [<bes modules dir>]]

bes_conf=${1:-"/etc/bes/bes.conf"}
bes_modules_dir=${2:-"/usr/lib/bes"}

# This script should take care to not add multiple entries for a handler.
# For now, I'm going to hack it so that a comment is written at the start
# of the file. This could be replaced by a better scheme, but probably not
# without rewrinting this in Perl or ...

if grep '^# Modified by bes-fonc-data\..*' $bes_conf >/dev/null 2>&1
then
	echo
	echo "The bes-fonc-data script has already been run, not modifying"
	echo "$bes_conf"
	echo
	exit
else
	echo "# Modified by bes-fonc-data.sh on `date`" >> $bes_conf
fi

# Add the handler name(s) to BES.modules
handler=fonc

sed "s%^\(BES.modules=.*\)%\1,$handler%" < $bes_conf > tmp.conf
mv tmp.conf $bes_conf

# Add the handler module line (e.g., BES.module.ff) to the conf file
module="BES.module.fonc=$bes_modules_dir/libfonc_module.so"

awk "BEGIN {bes_module_found=0}
	 /^BES\.module\./ {bes_module_found=1}
	 /^$/ && bes_module_found == 1 {print \"$module\"; bes_module_found=0}
	 {print}" \
	 < $bes_conf > tmp.conf
mv tmp.conf $bes_conf

# Set/append any handler-specific params.
comment_1="# File Out Netcdf (FONc) module specific parameters"
comment_2="# FONc.Tempdir: Directory to store temporary netcdf files during transformation"
comment_3="# FONc.Reference: URL to the FONc Reference Page at docs.opendap.org"
tmp_dir="FONc.Tempdir=/tmp"
ref="FONc.Reference=http://docs.opendap.org/index.php/BES_-_Modules_-_FileOut_Netcdf"

awk "BEGIN {fonc_found=0}
	/# Data Handler Specific/ {fonc_found=1}
	/^$/ && fonc_found == 1 {print}
	/^$/ && fonc_found == 1 {print \"$comment_1\"}
	/^$/ && fonc_found == 1 {print \"$comment_2\"}
	/^$/ && fonc_found == 1 {print \"$comment_3\"}
	/^$/ && fonc_found == 1 {print \"$ref\"}
	/^$/ && fonc_found == 1 {print \"$tmp_dir\"; fonc_found=0}
	{print}" \
	< $bes_conf > tmp.conf
mv tmp.conf $bes_conf

